pub struct PairingOutput<P: Pairing>(pub P::TargetField);Expand description
Represents the target group of a pairing. This struct is a wrapper around the field that the target group is embedded in.
Tuple Fields
0: P::TargetFieldTrait Implementations
Sourceimpl<'a, 'b, P: Pairing> Add<&'a PairingOutput<P>> for &'b PairingOutput<P>
impl<'a, 'b, P: Pairing> Add<&'a PairingOutput<P>> for &'b PairingOutput<P>
Sourcetype Output = PairingOutput<P>
type Output = PairingOutput<P>
The resulting type after applying the
+ operator.Sourcefn add(self, other: &'a PairingOutput<P>) -> PairingOutput<P>
fn add(self, other: &'a PairingOutput<P>) -> PairingOutput<P>
Performs the
+ operation. Read moreSourceimpl<'a, P: Pairing> Add<&'a PairingOutput<P>> for PairingOutput<P>
impl<'a, P: Pairing> Add<&'a PairingOutput<P>> for PairingOutput<P>
Sourceimpl<'a, 'b, P: Pairing> Add<&'a mut PairingOutput<P>> for &'b PairingOutput<P>
impl<'a, 'b, P: Pairing> Add<&'a mut PairingOutput<P>> for &'b PairingOutput<P>
Sourcetype Output = PairingOutput<P>
type Output = PairingOutput<P>
The resulting type after applying the
+ operator.Sourcefn add(self, other: &'a mut PairingOutput<P>) -> PairingOutput<P>
fn add(self, other: &'a mut PairingOutput<P>) -> PairingOutput<P>
Performs the
+ operation. Read moreSourceimpl<'a, P: Pairing> Add<&'a mut PairingOutput<P>> for PairingOutput<P>
impl<'a, P: Pairing> Add<&'a mut PairingOutput<P>> for PairingOutput<P>
Sourceimpl<'b, P: Pairing> Add<PairingOutput<P>> for &'b PairingOutput<P>
impl<'b, P: Pairing> Add<PairingOutput<P>> for &'b PairingOutput<P>
Sourcetype Output = PairingOutput<P>
type Output = PairingOutput<P>
The resulting type after applying the
+ operator.Sourcefn add(self, other: PairingOutput<P>) -> PairingOutput<P>
fn add(self, other: PairingOutput<P>) -> PairingOutput<P>
Performs the
+ operation. Read moreSourceimpl<P: Pairing> Add for PairingOutput<P>
impl<P: Pairing> Add for PairingOutput<P>
Sourceimpl<'a, P: Pairing> AddAssign<&'a PairingOutput<P>> for PairingOutput<P>
impl<'a, P: Pairing> AddAssign<&'a PairingOutput<P>> for PairingOutput<P>
Sourcefn add_assign(&mut self, other: &'a Self)
fn add_assign(&mut self, other: &'a Self)
Performs the
+= operation. Read moreSourceimpl<'a, P: Pairing> AddAssign<&'a mut PairingOutput<P>> for PairingOutput<P>
impl<'a, P: Pairing> AddAssign<&'a mut PairingOutput<P>> for PairingOutput<P>
Sourcefn add_assign(&mut self, other: &'a mut Self)
fn add_assign(&mut self, other: &'a mut Self)
Performs the
+= operation. Read moreSourceimpl<P: Pairing> AddAssign for PairingOutput<P>
impl<P: Pairing> AddAssign for PairingOutput<P>
Sourcefn add_assign(&mut self, other: Self)
fn add_assign(&mut self, other: Self)
Performs the
+= operation. Read moreSourceimpl<P: Pairing> AdditiveGroup for PairingOutput<P>
impl<P: Pairing> AdditiveGroup for PairingOutput<P>
Sourceimpl<P: Pairing> CanonicalDeserialize for PairingOutput<P>
impl<P: Pairing> CanonicalDeserialize for PairingOutput<P>
Sourcefn deserialize_with_mode<R: Read>(
reader: R,
compress: Compress,
validate: Validate,
) -> Result<Self, SerializationError>
fn deserialize_with_mode<R: Read>( reader: R, compress: Compress, validate: Validate, ) -> Result<Self, SerializationError>
The general deserialize method that takes in customization flags.
Sourcefn deserialize_compressed<R>(reader: R) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_compressed<R>(reader: R) -> Result<Self, SerializationError>where
R: Read,
Reads
Self from reader using the compressed form if applicable.
Performs validation if applicable.Sourcefn deserialize_compressed_unchecked<R>(
reader: R,
) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_compressed_unchecked<R>(
reader: R,
) -> Result<Self, SerializationError>where
R: Read,
Reads
Self from reader using the compressed form if applicable, without validating the
deserialized value. Read moreSourcefn deserialize_uncompressed<R>(reader: R) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_uncompressed<R>(reader: R) -> Result<Self, SerializationError>where
R: Read,
Reads
Self from reader using the uncompressed form. Performs validation if applicable.Sourcefn deserialize_uncompressed_unchecked<R>(
reader: R,
) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_uncompressed_unchecked<R>(
reader: R,
) -> Result<Self, SerializationError>where
R: Read,
Reads
Self from reader using the uncompressed form, without validating the deserialized
value. Read moreSourceimpl<P: Pairing> CanonicalSerialize for PairingOutput<P>
impl<P: Pairing> CanonicalSerialize for PairingOutput<P>
Sourcefn serialize_with_mode<W: Write>(
&self,
writer: W,
compress: Compress,
) -> Result<(), SerializationError>
fn serialize_with_mode<W: Write>( &self, writer: W, compress: Compress, ) -> Result<(), SerializationError>
The general serialize method that takes in customization flags.
Sourcefn serialized_size(&self, compress: Compress) -> usize
fn serialized_size(&self, compress: Compress) -> usize
Returns the size in bytes of the serialized version of
self with the given compression mode.Sourcefn serialize_compressed<W>(&self, writer: W) -> Result<(), SerializationError>where
W: Write,
fn serialize_compressed<W>(&self, writer: W) -> Result<(), SerializationError>where
W: Write,
Serializes
self into writer using the compressed form if applicable.Sourcefn compressed_size(&self) -> usize
fn compressed_size(&self) -> usize
Returns the size in bytes of the compressed serialized version of
self.Sourcefn serialize_uncompressed<W>(&self, writer: W) -> Result<(), SerializationError>where
W: Write,
fn serialize_uncompressed<W>(&self, writer: W) -> Result<(), SerializationError>where
W: Write,
Serializes
self into writer using the uncompressed form.Sourcefn uncompressed_size(&self) -> usize
fn uncompressed_size(&self) -> usize
Returns the size in bytes of the uncompressed serialized version of
self.Sourceimpl<P: Pairing> Clone for PairingOutput<P>where
P::TargetField: Copy,
impl<P: Pairing> Clone for PairingOutput<P>where
P::TargetField: Copy,
Sourceimpl<P: Pairing> Debug for PairingOutput<P>where
P::TargetField: Debug,
impl<P: Pairing> Debug for PairingOutput<P>where
P::TargetField: Debug,
Sourceimpl<P: Pairing> Default for PairingOutput<P>
impl<P: Pairing> Default for PairingOutput<P>
Sourceimpl<P: Pairing> Display for PairingOutput<P>
impl<P: Pairing> Display for PairingOutput<P>
Sourceimpl<P: Pairing> Distribution<PairingOutput<P>> for Standard
impl<P: Pairing> Distribution<PairingOutput<P>> for Standard
Sourcefn sample<R: Rng + ?Sized>(&self, rng: &mut R) -> PairingOutput<P>
fn sample<R: Rng + ?Sized>(&self, rng: &mut R) -> PairingOutput<P>
Generate a random value of
T, using rng as the source of randomness.Sourcefn sample_iter<R>(self, rng: R) -> DistIter<Self, R, T>
fn sample_iter<R>(self, rng: R) -> DistIter<Self, R, T>
Create an iterator that generates random values of
T, using rng as
the source of randomness. Read moreSourceimpl<P: Pairing> Hash for PairingOutput<P>where
P::TargetField: Hash,
impl<P: Pairing> Hash for PairingOutput<P>where
P::TargetField: Hash,
Sourceimpl<P: Pairing, T: Borrow<P::ScalarField>> Mul<T> for PairingOutput<P>
impl<P: Pairing, T: Borrow<P::ScalarField>> Mul<T> for PairingOutput<P>
Sourceimpl<P: Pairing, T: Borrow<P::ScalarField>> MulAssign<T> for PairingOutput<P>
impl<P: Pairing, T: Borrow<P::ScalarField>> MulAssign<T> for PairingOutput<P>
Sourcefn mul_assign(&mut self, other: T)
fn mul_assign(&mut self, other: T)
Performs the
*= operation. Read moreSourceimpl<P: Pairing> Neg for PairingOutput<P>
impl<P: Pairing> Neg for PairingOutput<P>
Sourceimpl<P: Pairing> Ord for PairingOutput<P>
impl<P: Pairing> Ord for PairingOutput<P>
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<P: Pairing> PartialEq for PairingOutput<P>where
P::TargetField: PartialEq,
impl<P: Pairing> PartialEq for PairingOutput<P>where
P::TargetField: PartialEq,
Sourceimpl<P: Pairing> PartialOrd for PairingOutput<P>
impl<P: Pairing> PartialOrd for PairingOutput<P>
Sourceimpl<P: Pairing> PrimeGroup for PairingOutput<P>
impl<P: Pairing> PrimeGroup for PairingOutput<P>
Sourcetype ScalarField = <P as Pairing>::ScalarField
type ScalarField = <P as Pairing>::ScalarField
The scalar field
F_r, where r is the order of this group.Sourcefn mul_bigint(&self, other: impl AsRef<[u64]>) -> Self
fn mul_bigint(&self, other: impl AsRef<[u64]>) -> Self
Performs scalar multiplication of this element.
Sourcefn mul_bits_be(&self, other: impl Iterator<Item = bool>) -> Self
fn mul_bits_be(&self, other: impl Iterator<Item = bool>) -> Self
Computes
other * self, where other is a big-endian
bit representation of some integer.Sourceimpl<P: Pairing> ScalarMul for PairingOutput<P>
impl<P: Pairing> ScalarMul for PairingOutput<P>
const NEGATION_IS_CHEAP: bool = <P::TargetField>::INVERSE_IS_FAST
type MulBase = PairingOutput<P>
fn batch_convert_to_mul_base(bases: &[Self]) -> Vec<Self::MulBase>
Sourcefn batch_mul(self, v: &[Self::ScalarField]) -> Vec<Self::MulBase>
fn batch_mul(self, v: &[Self::ScalarField]) -> Vec<Self::MulBase>
Compute the vector v[0].G, v[1].G, …, v[n-1].G, given: Read more
Sourcefn batch_mul_with_preprocessing(
table: &BatchMulPreprocessing<Self>,
v: &[Self::ScalarField],
) -> Vec<Self::MulBase>
fn batch_mul_with_preprocessing( table: &BatchMulPreprocessing<Self>, v: &[Self::ScalarField], ) -> Vec<Self::MulBase>
Compute the vector v[0].G, v[1].G, …, v[n-1].G, given: Read more
Sourceimpl<'a, 'b, P: Pairing> Sub<&'a PairingOutput<P>> for &'b PairingOutput<P>
impl<'a, 'b, P: Pairing> Sub<&'a PairingOutput<P>> for &'b PairingOutput<P>
Sourcetype Output = PairingOutput<P>
type Output = PairingOutput<P>
The resulting type after applying the
- operator.Sourcefn sub(self, other: &'a PairingOutput<P>) -> PairingOutput<P>
fn sub(self, other: &'a PairingOutput<P>) -> PairingOutput<P>
Performs the
- operation. Read moreSourceimpl<'a, P: Pairing> Sub<&'a PairingOutput<P>> for PairingOutput<P>
impl<'a, P: Pairing> Sub<&'a PairingOutput<P>> for PairingOutput<P>
Sourceimpl<'a, 'b, P: Pairing> Sub<&'a mut PairingOutput<P>> for &'b PairingOutput<P>
impl<'a, 'b, P: Pairing> Sub<&'a mut PairingOutput<P>> for &'b PairingOutput<P>
Sourcetype Output = PairingOutput<P>
type Output = PairingOutput<P>
The resulting type after applying the
- operator.Sourcefn sub(self, other: &'a mut PairingOutput<P>) -> PairingOutput<P>
fn sub(self, other: &'a mut PairingOutput<P>) -> PairingOutput<P>
Performs the
- operation. Read moreSourceimpl<'a, P: Pairing> Sub<&'a mut PairingOutput<P>> for PairingOutput<P>
impl<'a, P: Pairing> Sub<&'a mut PairingOutput<P>> for PairingOutput<P>
Sourceimpl<'b, P: Pairing> Sub<PairingOutput<P>> for &'b PairingOutput<P>
impl<'b, P: Pairing> Sub<PairingOutput<P>> for &'b PairingOutput<P>
Sourcetype Output = PairingOutput<P>
type Output = PairingOutput<P>
The resulting type after applying the
- operator.Sourcefn sub(self, other: PairingOutput<P>) -> PairingOutput<P>
fn sub(self, other: PairingOutput<P>) -> PairingOutput<P>
Performs the
- operation. Read moreSourceimpl<P: Pairing> Sub for PairingOutput<P>
impl<P: Pairing> Sub for PairingOutput<P>
Sourceimpl<'a, P: Pairing> SubAssign<&'a PairingOutput<P>> for PairingOutput<P>
impl<'a, P: Pairing> SubAssign<&'a PairingOutput<P>> for PairingOutput<P>
Sourcefn sub_assign(&mut self, other: &'a Self)
fn sub_assign(&mut self, other: &'a Self)
Performs the
-= operation. Read moreSourceimpl<'a, P: Pairing> SubAssign<&'a mut PairingOutput<P>> for PairingOutput<P>
impl<'a, P: Pairing> SubAssign<&'a mut PairingOutput<P>> for PairingOutput<P>
Sourcefn sub_assign(&mut self, other: &'a mut Self)
fn sub_assign(&mut self, other: &'a mut Self)
Performs the
-= operation. Read moreSourceimpl<P: Pairing> SubAssign for PairingOutput<P>
impl<P: Pairing> SubAssign for PairingOutput<P>
Sourcefn sub_assign(&mut self, other: Self)
fn sub_assign(&mut self, other: Self)
Performs the
-= operation. Read moreSourceimpl<'a, P: Pairing> Sum<&'a PairingOutput<P>> for PairingOutput<P>
impl<'a, P: Pairing> Sum<&'a PairingOutput<P>> for PairingOutput<P>
Sourceimpl<P: Pairing> Sum for PairingOutput<P>
impl<P: Pairing> Sum for PairingOutput<P>
Sourceimpl<P: Pairing> Valid for PairingOutput<P>
impl<P: Pairing> Valid for PairingOutput<P>
Sourcefn check(&self) -> Result<(), SerializationError>
fn check(&self) -> Result<(), SerializationError>
Checks whether
self is valid. If self is valid, returns Ok(()). Otherwise, returns
an error describing the failure.
This method is called by deserialize_with_mode if validate is Validate::Yes.Sourceconst TRIVIAL_CHECK: bool = false
const TRIVIAL_CHECK: bool = false
Whether the
check method is trivial (i.e. always returns Ok(())). If this is true,
the batch_check method will skip all checks and return Ok(()).
This should be set to true for types where check is trivial, e.g.
integers, field elements, etc.
This is false by default.
This is primarily an optimization to skip unnecessary checks in batch_check.Sourcefn batch_check<'a>(
batch: impl Iterator<Item = &'a Self> + Send,
) -> Result<(), SerializationError>where
Self: 'a,
fn batch_check<'a>(
batch: impl Iterator<Item = &'a Self> + Send,
) -> Result<(), SerializationError>where
Self: 'a,
Checks whether all items in
batch are valid. If all items are valid, returns Ok(()).
Otherwise, returns an error describing the first failure.Sourceimpl<P: Pairing> VariableBaseMSM for PairingOutput<P>
impl<P: Pairing> VariableBaseMSM for PairingOutput<P>
const ZERO_BUCKET: Self::Bucket = Self::ZERO
type Bucket = PairingOutput<P>
Sourcefn msm_unchecked(bases: &[Self::MulBase], scalars: &[Self::ScalarField]) -> Self
fn msm_unchecked(bases: &[Self::MulBase], scalars: &[Self::ScalarField]) -> Self
Computes an inner product between the
PrimeField elements in scalars
and the corresponding group elements in bases. Read moreSourcefn msm(
bases: &[Self::MulBase],
scalars: &[Self::ScalarField],
) -> Result<Self, usize>
fn msm( bases: &[Self::MulBase], scalars: &[Self::ScalarField], ) -> Result<Self, usize>
Performs multi-scalar multiplication. Read more
Sourcefn msm_bigint(
bases: &[Self::MulBase],
bigints: &[<Self::ScalarField as PrimeField>::BigInt],
) -> Self
fn msm_bigint( bases: &[Self::MulBase], bigints: &[<Self::ScalarField as PrimeField>::BigInt], ) -> Self
Optimized implementation of multi-scalar multiplication.
Sourcefn msm_u1(bases: &[Self::MulBase], scalars: &[bool]) -> Self
fn msm_u1(bases: &[Self::MulBase], scalars: &[bool]) -> Self
Performs multi-scalar multiplication when the scalars are known to be boolean.
The default implementation is faster than
Self::msm_bigint.Sourcefn msm_u8(bases: &[Self::MulBase], scalars: &[u8]) -> Self
fn msm_u8(bases: &[Self::MulBase], scalars: &[u8]) -> Self
Performs multi-scalar multiplication when the scalars are known to be
u8-sized.
The default implementation is faster than Self::msm_bigint.Sourcefn msm_u16(bases: &[Self::MulBase], scalars: &[u16]) -> Self
fn msm_u16(bases: &[Self::MulBase], scalars: &[u16]) -> Self
Performs multi-scalar multiplication when the scalars are known to be
u16-sized.
The default implementation is faster than Self::msm_bigint.Sourcefn msm_u32(bases: &[Self::MulBase], scalars: &[u32]) -> Self
fn msm_u32(bases: &[Self::MulBase], scalars: &[u32]) -> Self
Performs multi-scalar multiplication when the scalars are known to be
u32-sized.
The default implementation is faster than Self::msm_bigint.Sourceimpl<P: Pairing> Zero for PairingOutput<P>
impl<P: Pairing> Zero for PairingOutput<P>
Sourceimpl<P: Pairing> Zeroize for PairingOutput<P>
impl<P: Pairing> Zeroize for PairingOutput<P>
impl<P: Pairing> Copy for PairingOutput<P>where
P::TargetField: Copy,
impl<P: Pairing> Eq for PairingOutput<P>where
P::TargetField: PartialEq,